@@ -5,6 +5,10 @@ use React\ChildProcess\Process;
 
 require __DIR__ . '/../vendor/autoload.php';
 
+if (DIRECTORY_SEPARATOR === '\\') {
+    exit('Process pipes not supported on Windows' . PHP_EOL);
+}
+
 $loop = Factory::create();
 
 $first = new Process('sleep 2; echo welt');
