@@ -8,7 +8,7 @@ require __DIR__ . '/../vendor/autoload.php';
 $loop = Factory::create();
 
 // start a process that takes 10s to terminate
-$process = new Process('sleep 10');
+$process = new Process('php -r "sleep(10);"', null, null, array());
 $process->start($loop);
 
 // report when process exits
@@ -18,9 +18,9 @@ $process->on('exit', function ($exit, $term) {
 
 // forcefully terminate process after 2s
 $loop->addTimer(2.0, function () use ($process) {
-    $process->stdin->close();
-    $process->stdout->close();
-    $process->stderr->close();
+    foreach ($process->pipes as $pipe) {
+        $pipe->close();
+    }
     $process->terminate();
 });
 
